@@ -7,6 +7,7 @@
 #include "utils.h"
 
 #include <kscreen/edid.h>
+#include <kscreen/mode.h>
 
 #include <KLocalizedString>
 
@@ -48,3 +49,29 @@ QString Utils::sizeToString(const QSize &size)
 {
     return QStringLiteral("%1x%2").arg(size.width()).arg(size.height());
 }
+
+KScreen::ModePtr Utils::biggestMode(const KScreen::ModeList &modes)
+{
+    Q_ASSERT(!modes.isEmpty());
+
+    int modeArea, biggestArea = 0;
+    KScreen::ModePtr biggestMode;
+    for (const KScreen::ModePtr &mode : modes) {
+        modeArea = mode->size().width() * mode->size().height();
+        if (modeArea < biggestArea) {
+            continue;
+        }
+        if (modeArea == biggestArea && mode->refreshRate() < biggestMode->refreshRate()) {
+            continue;
+        }
+        if (modeArea == biggestArea && mode->refreshRate() > biggestMode->refreshRate()) {
+            biggestMode = mode;
+            continue;
+        }
+
+        biggestArea = modeArea;
+        biggestMode = mode;
+    }
+
+    return biggestMode;
+}
